#### Getting started: Read in Data, prepare tables and seperate data for analysis ----
setwd("D:/PhD/Mitebreeding/Publication") #workign directly R files and datasets
data <- xlsx::read.xlsx("Mitedata.xlsx",sheetIndex = 2) #total number of eggs witg productivity
Nutrients<-xlsx::read.xlsx("Nutrients.xlsx",sheetIndex =1 )#nutrient data
library(ggplot2)
library(ggpubr)
library(DescTools)
library(dplyr)
library(lme4)
library(dplyr)
library("MASS")
library(broom)
library(clipr)
library(magrittr)

data$Tre<-as.factor(data$Tre)
data$Treatment<-as.factor(data$Treatment)
Nutrients$Tre<-as.factor(Nutrients$Tre)
Nutrients$Tree<-as.factor(Nutrients$Tree)
Nutrients$Season<-as.factor(Nutrients$Season)
Nutrients$NP<-Nutrients$N/Nutrients$P
Nutrients$CN<-Nutrients$C/Nutrients$N
Nutrients$CNP<-Nutrients$C/Nutrients$N/Nutrients$P
Nutrients[is.na(Nutrients)] <- 0
#combine nutrients and mite data for modelling in one table called merged_data
merged_data <- merge(data, Nutrients, by = "Tre", all.x = TRUE)

merged_data$Tre<-as.factor(merged_data$Tre)
merged_data$Tre<-relevel(merged_data$Tre, ref= "Con")
merged_data$Tree<-relevel(merged_data$Tree, ref="Con")
merged_data$Season<-relevel(merged_data$Season, ref= "Con")
#In this script, it will be worked further with a dataset excluding the treatment ALgDry and AlgWet, that can still be found in the raw dataset of the excel sheet
NoAlgDat <- merged_data[!(merged_data$Tre %in% c("AlgWet", "AlgDry")), ]
NoAlgNu<-Nutrients[!(Nutrients$Tre %in% c("AlgWet", "AlgDry", "Con")), ] #also no Con!
NoAlgNu$Tre<-droplevels(NoAlgNu$Tre)
NoAlgDat$Tre<-droplevels(NoAlgDat$Tre)
NoAlgDat$Season<-droplevels(NoAlgDat$Season)
NoAlgDat$Tree<-droplevels(NoAlgDat$Tree)

#### Test to see if basic requirements for linear model are fulfilled ----
LeveneTest(NoAlgDat$ProuctivityWeighted~NoAlgDat$Tre)%>%
  tidy() %>%
  write_clip()
shapiro.test(NoAlgDat$ProuctivityWeighted)%>%
  tidy() %>%
  write_clip()
shapiro.test(log(NoAlgDat$ProuctivityWeighted))%>%
  tidy() %>%
  write_clip()


#### Plots presented in the paper ----
desired_orderNu <- c("PV", "PZ", "PN", "QV", "QZ", "QN")
NoAlgNu$Tre<-factor(NoAlgNu$Tre, levels = desired_orderNu)
nucol<-c("#8fbc8f", "#3cb371", "#2e8b57", "#deb887", "#a0522d", "#8b4513")

p1<-ggplot(NoAlgNu, aes(x = Tre, y = N, fill = Tre)) +
  geom_bar(stat = "identity", position = "dodge") +
  scale_fill_manual(values = nucol) +
  xlab("") +
  ylab("PPM") +
  ggtitle("Nitrogen content") +
  labs(fill = "Treatment ") +
  theme(legend.position = "none") +
  theme(axis.title.x = element_blank(), axis.text.x = element_blank())
p2<-ggplot(NoAlgNu, aes(x = Tre, y = P, fill = Tre)) +
  geom_bar(stat = "identity", position = "dodge") +
  scale_fill_manual(values = nucol) +
  xlab("") +
  ylab("PPM") +
  ggtitle("Phosphorus content") +
  theme(legend.position = "none") +
  theme(axis.title.x = element_blank(), axis.text.x = element_blank()) 
p3<-ggplot(NoAlgNu, aes(x = Tre, y = Phenols_mgL, fill = Tre)) +
  geom_bar(stat = "identity", position = "dodge") +
  scale_fill_manual(values = nucol) +
  xlab("") +
  ylab("PPM") +
  ggtitle("Phenolic content") +
  theme(legend.position = "none") +
  theme(axis.title.x = element_blank(), axis.text.x = element_blank()) 
arranged_plot <- ggarrange(p1, p2, p3, ncol = 3, common.legend = TRUE, legend = "right", align = "hv")

# Print the final arranged plot
print(arranged_plot)


#reproduce same kind of plot for silicon and potassium; 
k1<-ggplot(NoAlgNu, aes(x = Tre, y = K_7664, fill = Tre)) +
  geom_bar(stat = "identity", position = "dodge") +
  scale_fill_manual(values = nucol) +
  xlab("") +
  ylab("PPM") +
  labs(fill = "Treatment ") +
  ggtitle("Potassium content") +
  theme(legend.position = "none") +
  theme(axis.title.x = element_blank(), axis.text.x = element_blank())

Si1<-ggplot(NoAlgNu, aes(x = Tre, y = Si2516, fill = Tre)) +
  geom_bar(stat = "identity", position = "dodge") +
  scale_fill_manual(values = nucol) +
  xlab("") +
  ylab("PPM") +
  ggtitle("Silicon content") +
  theme(legend.position = "none") +
  theme(axis.title.x = element_blank(), axis.text.x = element_blank())

arranged_plot <- ggarrange(k1, Si1, ncol = 2, common.legend = TRUE, legend = "right", align = "hv")
print(arranged_plot)

#violin plot with results of productivity as a measure of laid eggs
NoAlg<-data[!(data$Tre %in% c("AlgWet", "AlgDry")), ]
desired_order2 <- c("Con", "PV", "PZ", "PN", "QV", "QZ", "QN")
NoAlg$Tre<-factor(NoAlg$Tre, levels = desired_order2)
prodpal1<-c("#FFFFFF","#8fbc8f", "#3cb371", "#2e8b57", "#deb887", "#a0522d", "#8b4513")

Prod2<- ggplot(NoAlg, aes(x = Tre, y = ProuctivityWeighted)) +
  geom_violin(aes(fill = Tre), color = "black", scale="width") +
  geom_boxplot(width = 0.5, fill = prodpal1, color = "black") +
  scale_fill_manual(values = prodpal1) +  # Use custom color palette
  labs(x = "", y = "Productivity", title = "Productivity as a measure of egg laying of Platynothrus peltifer") +
  labs(fill="Treatments") +
  theme_minimal() +
  theme(plot.title = element_text(hjust = 0.5)) +
  geom_text(data = subset(NoAlg, Tre == "PV"), aes(x = Tre, y = max(ProuctivityWeighted), label = "a"), vjust = -1)+
  geom_text(data = subset(NoAlg, Tre %in% c("PZ", "PN", "QN", "Con")), aes(x = Tre, y = max(ProuctivityWeighted), label = "b"), vjust = -1)+
  geom_text(data = subset(NoAlg, Tre %in% c("QV", "QZ")), aes(x = Tre, y = max(ProuctivityWeighted), label = "ab"), vjust = -1)

print(Prod2)

#### Linear models to link nutrients with productivity as a measure of reproductive response----
NoAlgDat$Tre<-relevel(NoAlgDat$Tre, ref="Con")
subset_df <- NoAlgNu[, c("C", "N", "P", "Phenols_mgL")]
subset_df2<-NoAlgNu[, c("Ca3179", "Fe2599", "K_7664", "Mg", "Mn2576", "Na5889", "S_1820", "Si2516","Zn2138")]
cormat1<-cor(subset_df2)
cormat2<-cor(subset_df)
#phenols is storngly correlated with C, probably because part of the C is also ohenols.
write.csv(cormat2, file = "correlation_matrix.csv")




lmCNP1<-lm(ProuctivityWeighted~C, data=NoAlgDat)
summary(lmCNP1)
lmCNP2<-lm(ProuctivityWeighted~N, data=NoAlgDat)
summary(lmCNP2)
lmCNP3<-lm(ProuctivityWeighted~P, data=NoAlgDat)
summary(lmCNP3)
lmCNP4<-lm(ProuctivityWeighted~C+N, data=NoAlgDat)
VIF(lmCNP4)
summary(lmCNP4)
lmCNP5<-lm(ProuctivityWeighted~C+P, data=NoAlgDat)
summary(lmCNP5)
VIF(lmCNP5)#higher, not so okay, left out
lmCNP6<-lm(ProuctivityWeighted~N+P, data=NoAlgDat)
summary(lmCNP6)#this is okay
VIF(lmCNP6)
lmCNP7<-lm(ProuctivityWeighted~NP, data=NoAlgDat)
summary(lmCNP7)
AIC(lmCNP7)
lmCNP8<-lm(ProuctivityWeighted~CN, data=NoAlgDat)
summary(lmCNP8)
lmCNP9<-lm(ProuctivityWeighted~CNP, data=NoAlgDat)
summary(lmCNP9)
lmCNP10<-lm(ProuctivityWeighted~C+NP, data=NoAlgDat)
summary(lmCNP10)
VIF(lmCNP10)
lmCNP11<-lm(ProuctivityWeighted~CN+P, data=NoAlgDat)
summary(lmCNP11)
VIF(lmCNP11)#is okay
lmCNP12<-lm(ProuctivityWeighted~C:N:P, data=NoAlgDat)
summary(lmCNP12)
lmCNP13<-lm(ProuctivityWeighted~N:P, data=NoAlgDat)
summary(lmCNP13)
lmCNP14<-lm(ProuctivityWeighted~C:N, data=NoAlgDat)
summary(lmCNP14)
lmCNP15<-lm(ProuctivityWeighted~C+P+N, data=NoAlgDat)
summary(lmCNP15)
VIF(lmCNP15)#C is very high
lmCNP16<-lm(ProuctivityWeighted~Phenols_mgL+P, data=NoAlgDat)
summary(lmCNP16)
lmCNP17<-lm(ProuctivityWeighted~Phenols_mgL+N, data=NoAlgDat)
summary(lmCNP17)
lmCNP18<-lm(ProuctivityWeighted~Phenols_mgL+N+P, data=NoAlgDat)
summary(lmCNP18)
VIF(lmCNP18)
lmCNP19<-lm(ProuctivityWeighted~Phenols_mgL+C, data=NoAlgDat)
summary(lmCNP19)
lmCNP20<-lm(ProuctivityWeighted~Phenols_mgL+CN, data=NoAlgDat)
summary(lmCNP20)
lmCNP21<-lm(ProuctivityWeighted~Phenols_mgL+NP, data=NoAlgDat)
summary(lmCNP21)
lmCNP22<-lm(ProuctivityWeighted~Phenols_mgL+CNP, data=NoAlgDat)
summary(lmCNP22)
# Create an empty data frame to store the coefficients
coefficients_df <- data.frame()
model_list <- list(lmCNP1, lmCNP2, lmCNP3, lmCNP4, lmCNP5, lmCNP6, lmCNP7, lmCNP8, lmCNP9, lmCNP10, lmCNP11,lmCNP12,lmCNP13,lmCNP14,lmCNP15,lmCNP16,lmCNP17,lmCNP18, lmCNP19, lmCNP20, lmCNP21,lmCNP22)
# Loop through each model in the list
for(i in 1:length(model_list)){
  # Get the coefficients of the model
  coefficients <- coef(model_list[[i]])
  
  # Convert the coefficients to a data frame
  coefficients_df_temp <- as.data.frame(t(coefficients), stringsAsFactors = FALSE)
  
  # Add a column for the model name
  coefficients_df_temp$model_name <- paste0("lmCNP", i)
  
  # Bind the coefficients data frame to the main data frame
  # Use bind_rows from dplyr which can handle different column names
  coefficients_df <- dplyr::bind_rows(coefficients_df, coefficients_df_temp)
}

# Write the data frame to a CSV file
write.csv(coefficients_df, "model_coefficients.csv", row.names = FALSE)

AICs<-AIC(lmCNP1, lmCNP2, lmCNP3, lmCNP4, lmCNP5, lmCNP6, lmCNP7, lmCNP8, lmCNP9, lmCNP10, lmCNP11,lmCNP12,lmCNP13,lmCNP14,lmCNP15,lmCNP16,lmCNP17,lmCNP18, lmCNP19, lmCNP20, lmCNP21,lmCNP22)
weight<-akaike.weights(AICs$AIC)
AICs<-cbind(AICs, weight)  
AICs<-AICs[order(AICs$weights, decreasing=T),]
AICs
write.csv(AICs, file = "AICS.csv")


lmPPM1<-lm(ProuctivityWeighted~Ca3179, data=NoAlgDat)
summary(lmPPM1)#not sn
lmPPM2<-lm(ProuctivityWeighted~Fe2599, data=NoAlgDat)
summary(lmPPM2)#notsn
lmPPM3<-lm(ProuctivityWeighted~K_7664, data=NoAlgDat)
summary(lmPPM3)#is sn and explains 30 %
lmPPM4<-lm(ProuctivityWeighted~Mg, data=NoAlgDat)
summary(lmPPM4)#not sn 
lmPPM6<-lm(ProuctivityWeighted~Mn2576, data=NoAlgDat)
summary(lmPPM6)#not sn
lmPPM7<-lm(ProuctivityWeighted~Na5889, data=NoAlgDat)
summary(lmPPM7)#significANT   
lmPPM8<-lm(ProuctivityWeighted~S_1820, data=NoAlgDat)
summary(lmPPM8)#not sn
lmPPM9<-lm(ProuctivityWeighted~Si2516, data=NoAlgDat)
summary(lmPPM9)#almost sn
lmPPM10<-lm(ProuctivityWeighted~Zn2138, data=NoAlgDat)
summary(lmPPM10)#not sn

lmNut1<-lm(ProuctivityWeighted~K_7664+Na5889, data=NoAlgDat)
summary(lmNut1)
lmNut2<-lm(ProuctivityWeighted~K_7664+Si2516, data=NoAlgDat)%>%
  tidy() %>%
  write_clip()
summary(lmNut2)
lmNut3<-lm(ProuctivityWeighted~Na5889+Si2516, data=NoAlgDat)
summary(lmNut3)
VIF(lmNut2)%>%
  tidy() %>%
  write_clip()
lmNut4<-lm(ProuctivityWeighted~Na5889+Si2516+K_7664, data=NoAlgDat)
summary(lmNut4)

AICs<-AIC(lmNut1, lmNut2, lmNut3, lmNut4)
weight<-akaike.weights(AICs$AIC)
AICs<-cbind(AICs, weight)  
AICs<-AICs[order(AICs$weights, decreasing=T),]
AICs